<?php

namespace Drupal\genoring\Controller;

/**
 * GenoRing taxonomy page controller.
 */

use Drupal\Core\Controller\ControllerBase;
use Drupal\genoring\Taxonomy\TaxonomyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * TaxonomyController class.
 *
 * Provides taxonomy auto-complete features.
 */
class TaxonomyController extends ControllerBase {

  /**
   * The taxonomy service.
   *
   * @var \Drupal\genoring\Taxonomy\TaxonomyInterface
   */
  protected $taxonomyManager;

  /**
   * Constructs an AutocompleteController object.
   *
   * @param \Drupal\genoring\Taxonomy\TaxonomyInterface $taxonomy_manager
   *   The taxonomy service.
   */
  public function __construct(
    #[Autowire(service: 'genoring.taxonomy')]
    TaxonomyInterface $taxonomy_manager,
  ) {
    $this->taxonomyManager = $taxonomy_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('genoring.taxonomy')
    );
  }

  /**
   * Handles autocomplete request.
   */
  public function handleAutocomplete(Request $request) {
    $input = $request->query->get('q');
    $mode = $request->query->get('m');
    if (empty($mode)) {
      $mode = TaxonomyInterface::MATCH_TAXONOMY_ANY;
    }
    elseif ('taxid' === $mode) {
      $mode = TaxonomyInterface::MATCH_TAXONOMY_TAXID;
    }
    elseif ('code' === $mode) {
      $mode = TaxonomyInterface::MATCH_TAXONOMY_CODE;
    }
    elseif ('name' === $mode) {
      $mode = TaxonomyInterface::MATCH_TAXONOMY_NAME;
    }
    else {
      $mode = TaxonomyInterface::MATCH_TAXONOMY_ANY;
    }

    $matches = [];

    if ($input) {
      $matches = $this->taxonomyManager->matchTaxonomy($input, $mode);
    }

    return new JsonResponse($matches);
  }

}
