<?php

namespace Drupal\genoring\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * The Type Metadata Event.
 *
 * Provides a way to gather metadata fields that are related to a given file
 * type.
 */
class DataTypeMetadataEvent extends Event {

  /**
   * The metadata field structure with field form elements.
   *
   * @var array
   */
  protected $metadataFields;

  /**
   * Constructs a compatible data model event object.
   */
  public function __construct() {
    $this->metadataFields = [];
  }

  /**
   * Gets the list of metadata fields.
   *
   * @return array
   *   A list of metadata fields.
   */
  public function getMetadataFields() :array {
    return $this->metadataFields;
  }

  /**
   * Add a metadata field.
   *
   * @param string $type
   *   The machine name of the type of data.
   * @param string $field_id
   *   A field identifier for the form element.
   * @param array $field_info
   *   The field element info structure. The structure is descibbed in
   *   \Drupal\genoring\DataManager\DataManagerInterface::generateFormField().
   *
   * @return self
   *   Current instance.
   */
  public function addMetadataField(
    string $type,
    string $field_id,
    array $field_info,
  ) :self {
    $this->metadataFields[$type] ??= [];
    $this->metadataFields[$type][$field_id] = $field_info;
    return $this;
  }

}
