<?php

namespace Drupal\genoring\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\genoring\DataManager\DataManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the data manager configuration form.
 */
class DataManagerForm extends FormBase {

  /**
   * The data manager.
   *
   * @var \Drupal\genoring\DataManager\DataManagerInterface
   */
  protected $dataManager;

  /**
   * Constructs an DataManagerForm object.
   *
   * @param \Drupal\genoring\DataManager\DataManagerInterface $data_manager
   *   The data processor manager.
   */
  public function __construct(
    DataManagerInterface $data_manager,
  ) {
    $this->dataManager = $data_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('genoring.data_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'genoring_data_manager_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Set a predictible id.
    $form['#attributes'] += [
      'id' => 'genoring_dm',
    ];

    $form['info'] = [
      '#type' => 'item',
      '#markup' => $this->t(
        "Here, you can configure default data directories.",
      ),
    ];

    $form = $this->dataManager->buildDirectoryConfigurationForm($form, $form_state);

    // Actions.
    $form['actions'] ??= [
      '#type' => 'actions',
    ];

    $form['actions']['save'] ??= [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $this->dataManager->validateDirectoryConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->dataManager->submitDirectoryConfigurationForm($form, $form_state);
  }

}
