<?php

namespace Drupal\genoring\Form;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the data processor form.
 *
 * The data processor form enables to upload new files and perfom operations on
 * managed data files and save generated files at the appropriate place.
 */
class DataProcessorForm extends FormBase {

  /**
   * The data processor manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $dataProcessorManager;

  /**
   * The current data processing context.
   *
   * @var array
   */
  protected $context = [];

  /**
   * Constructs an DataProcessorForm object.
   *
   * @param \Drupal\Component\Plugin\PluginManagerInterface $data_processor_manager
   *   The data processor manager.
   */
  public function __construct(
    PluginManagerInterface $data_processor_manager,
  ) {
    $this->dataProcessorManager = $data_processor_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.genoring.data_processor')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'genoring_data_processor_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // @todo Manage multiple input files.
    $form['input'] = [
      '#type' => 'genoring_input',
      '#title' => $this->t('Input file'),
    ];

    // Actions.
    $form['actions'] ??= [
      '#type' => 'actions',
    ];

    $form['actions']['manage'] ??= [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => $this->t('Manage file'),
      // @todo Hide if selecting an already managed file.
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

}
