<?php

namespace Drupal\genoring\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\genoring\Taxonomy\TaxonomyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the taxonomy management form.
 */
class TaxonomyManagerForm extends FormBase {

  /**
   * The taxonomy manager.
   *
   * @var \Drupal\genoring\Taxonomy\TaxonomyInterface
   */
  protected $taxonomyManager;

  /**
   * Constructs an TaxonomyManagerForm object.
   *
   * @param \Drupal\genoring\Taxonomy\TaxonomyInterface $taxonomy_manager
   *   The taxonomy manager.
   */
  public function __construct(
    TaxonomyInterface $taxonomy_manager,
  ) {
    $this->taxonomyManager = $taxonomy_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('genoring.taxonomy')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'genoring_taxonomy_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $species = $this->taxonomyManager->getSpecies();
    $species_count = $this->formatPlural(
      count($species),
      '1 species code record',
      '@count species code records'
    );
    $form['info'] = [
      '#type' => 'item',
      '#markup' => $this->t(
        'Current taxonomy data contains @species_count.',
        ['@species_count' => $species_count]
      ),
    ];

    // @todo Add species code/name search form.

    $form['reload'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Reload taxonomy'),
    ];
    $form['reload']['remove_file'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Re-download speclits.txt file from UniProt'),
      '#default_value' => 0,
    ];
    $form['reload']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reload taxonomy'),
      '#submit' => ['::submitReloadTaxonomy'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * Reload taxonomy data.
   *
   * @param array $form
   *   The current form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   */
  public function submitReloadTaxonomy(array &$form, FormStateInterface $form_state) {
    if ($form_state->getValue('remove_file')) {
      $this->taxonomyManager->removeTaxonomyFile();
    }
    // @todo Use batch API.
    $this->taxonomyManager->loadTaxonomy();
    // Check if something was loaded.
    $species = $this->taxonomyManager->getSpecies();
    if (!empty($species)) {
      \Drupal::messenger()->addMessage('Taxonomy successfully reloaded.');
    }
    else {
      \Drupal::messenger()->addWarning('Failed to reload taxonomy. See logs for details.');
    }
  }

}
