<?php

namespace Drupal\genoring\Plugin\Genoring\DataLocator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\genoring\DataLocator\DataLocatorBase;
use Drupal\genoring\DataManager\DataManager;

/**
 * Default data locator.
 *
 * @DataLocator(
 *   id = "default",
 *   label = @Translation("Base locator"),
 *   description = @Translation("Data locator used to place files in the configured default data path (and scheme)."),
 *   defaultSupportedMetadata = {}
 * )
 */
class DefaultLocator extends DataLocatorBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'data_uri' => DataManager::$defaultConfiguration['data_uri'],
      'replace' => 0,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state,
  ) {
    $configuration = $this->getConfiguration();
    $form['data_uri'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Base data URI:'),
      '#description' => $this->t('Can include a data scheme (ie. private/public). The trailing slash is not required here.'),
      '#required' => TRUE,
      '#attributes' => [
        'placeholder' => t('private://genoring'),
      ],
      '#size' => 40,
      '#wrapper_attributes' => ['class' => ['container-inline']],
      '#default_value' => $form_state->getValue(
        'data_uri',
        $configuration['data_uri']
        ?? NULL
        ?: static::defaultConfiguration()['data_uri']
      ),
    ];
    $form['replace'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Replace current scheme and directory'),
      '#description' => $this->t('If checked, any previous file path is replaced by the one provided here and only the file name is kept. Otherwise, the provided scheme will be only used if missing in the file URI and the provided path will be prefixed to the given file path.'),
      '#default_value' => $form_state->getValue(
        'replace',
        $configuration['replace']
        ?? NULL
        ?: static::defaultConfiguration()['replace']
      ),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function locateUri(
    array $metadata,
    string $base_uri = '',
  ) :string {
    $configuration = $this->getConfiguration();

    [$base_stream, $base_path, $base_filename] = $this->explodeUri($base_uri, TRUE);
    [$conf_stream, $conf_path, $conf_filename] = $this->explodeUri(($configuration['data_uri'] ?? DataManager::$defaultConfiguration['data_uri']), TRUE);
    // We should not have files in config but a missing trailing slash.
    $conf_path .= $conf_filename;
    if (!empty($conf_path)) {
      $conf_path = rtrim($conf_path, '/') . '/';
    }
    $default_stream = (strstr(rtrim(DataManager::$defaultConfiguration['data_uri'], '/') . '/', '://', TRUE) ?: 'public') . '://';
    // Check slected behavior.
    if (empty($configuration['replace'])) {
      // Keep given $base_uri and just add what is missing.
      $uri = ($base_stream ?? $conf_stream ?? $default_stream) . $conf_path . $base_path . $base_filename;
    }
    else {
      // Replace everything and just keep file name.
      $uri = ($conf_stream ?? $base_stream ?? $default_stream) . $conf_path . $base_filename;
    }

    return $uri;
  }

}
