<?php

namespace Drupal\genoring\Plugin\Genoring\DataLocator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\genoring\DataLocator\DataLocatorBase;

/**
 * Metadata locator.
 *
 * @DataLocator(
 *   id = "metadata",
 *   label = @Translation("Metadata locator"),
 *   description = @Translation("Data locator used to place metadata files."),
 *   defaultSupportedMetadata = {"+format=metadata,targetUri"}
 * )
 */
class MetadataLocator extends DataLocatorBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'data_uri' => '.metadata',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state,
  ) {
    $configuration = $this->getConfiguration();
    $form['data_uri'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Metadata suffix:'),
      '#description' => $this->t('The suffix appended to data file or name of the sub-directory holding the metadata files.'),
      '#required' => TRUE,
      '#attributes' => [
        'placeholder' => t('.metadata'),
      ],
      '#size' => 40,
      '#wrapper_attributes' => ['class' => ['container-inline']],
      '#default_value' => $form_state->getValue(
        'data_uri',
        $configuration['data_uri']
        ?? ''
        ?: $this->defaultConfiguration()['data_uri']
      ),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function locateUri(
    array $metadata,
    string $base_uri = '',
  ) :string {
    $uri = $base_uri;
    if (!empty($metadata['targetUri'])) {
      $uri = $metadata['targetUri'];
    }
    [$stream, $path, $filename] = $this->explodeUri($uri);
    $configuration = $this->getConfiguration();
    $metadata_directory = empty($configuration['data_uri']) ? '' : $configuration['data_uri'] . '/';
    $metadata_extension = $configuration['data_uri'] ?? '' ?: $this->defaultConfiguration()['data_uri'];
    if (empty($metadata['targetType']) || ('file' === $metadata['targetType'])) {
      $uri = $stream . $path . $metadata_directory . $filename . $metadata_extension;
    }
    elseif ('directory' === $metadata['targetType']) {
      $uri = $stream . $path . $metadata_directory;
    }
    return $uri;
  }

}
