<?php

namespace Drupal\Tests\genoring\Unit;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Tests\UnitTestCase;
use Drupal\genoring\Plugin\Genoring\DataLocator\MetadataLocator;

/**
 * The class to test taxonomy data locator.
 *
 * @group genoring
 */
class DataLocatorMetadataUnitTest extends UnitTestCase {

  /**
   * Data provider for testStringCaseProcessor().
   *
   * Structure:
   * - expected_uri
   * - base_uri
   * - metadata
   * - config
   * - test name.
   */
  public static function provideTestMetadataDataLocator() {
    return [
      [
        'private://genoring/somebase/',
        'private://genoring/somebase/',
        [],
        [],
        'No type, no config',
      ],
      [
        'private://genoring/somebase/somefile.txt.metadata',
        'private://genoring/somebase/somefile.txt',
        [
          'type' => 'file',
        ],
        [],
        'File type, no config',
      ],
      [
        'private://genoring/somebase/somefile.txt.metadata',
        'private://genoring/somebase/somefile.txt',
        [
          'type' => 'file',
        ],
        [
          'data_uri' => '',
        ],
        'File type, with config',
      ],
      [
        'private://genoring/somebase/',
        'private://genoring/somebase/',
        [],
        [
          'data_uri' => '.meta',
        ],
        'No type, with config',
      ],
      [
        'private://genoring/somebase/',
        'private://genoring/somebase/',
        [
          'type' => 'directory',
        ],
        [
          'data_uri' => '',
        ],
        'Direcotry type, with config',
      ],
      [
        'private://genoring/somebase/.meta/',
        'private://genoring/somebase/',
        [
          'type' => 'directory',
        ],
        [
          'data_uri' => '.meta',
        ],
        'Direcotry type, with config',
      ],
      [
        'private://genoring/somebase/.meta/somefile.txt.meta',
        'private://genoring/somebase/somefile.txt',
        [
          'type' => 'file',
        ],
        [
          'data_uri' => '.meta',
        ],
        'File type, with config',
      ],
    ];
  }

  /**
   * Tests metadata data locator.
   *
   * @dataProvider provideTestMetadataDataLocator
   */
  public function testMetadataDataLocator(
    string $expected_uri,
    string $base_uri,
    array $metadata,
    array $config,
    string $test_name,
  ) {
    $string_translation = $this->createMock(TranslationInterface::class);

    $logger = $this->createMock(LoggerChannelInterface::class);
    $logger_factory = $this->createMock(LoggerChannelFactoryInterface::class);
    $logger_factory
      ->expects($this->any())
      ->method('get')
      ->with('genoring_locator_metadata')
      ->willReturn($logger);

    $data_locator = new MetadataLocator($config, 'metadata', [], $string_translation, $logger_factory);
    $result_uri = $data_locator->locateUri($metadata, $base_uri);
    $this->assertEquals($expected_uri, $result_uri, $test_name);
  }

}
