<?php

namespace Drupal\Tests\genoring\Unit;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Tests\UnitTestCase;

/**
 * The class to test data manager service.
 *
 * @group genoring
 */
class DataManagerTest extends UnitTestCase {

  /**
   * Test container.
   *
   * @var \Symfony\Component\DependencyInjection\ContainerInterface
   */
  protected $container;

  /**
   * Mocked taxonomy serice.
   *
   * @var \SDrupal\genoring\Taxonomy\TaxonomyInterface
   */
  protected $taxonomyServiceMock;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $container = new ContainerBuilder();

    // Create a mock for the taxonomy service.
    $taxonomy_lookup = [];
    $this->taxonomyServiceMock = $this->createMock(TaxonomyInterface::class);
    $this->taxonomyServiceMock->method('getSpeciesCode')
      ->willReturnCallback(function (string $string) use ($taxonomy_lookup) {
        return $taxonomy_lookup['species_codes'][$string] ?? TaxonomyInterface::SPECIES_CODE_UNKNOWN;
      });
    $this->taxonomyServiceMock->method('getTaxonomyId')
      ->willReturnCallback(function (string $string) use ($taxonomy_lookup) {
        return $taxonomy_lookup['taxid'][$string] ?? TaxonomyInterface::TAXONOMY_ID_UNKNOWN;
      });
    $this->taxonomyServiceMock->method('getNormalizedSpeciesName')
      ->willReturnCallback(function (string $string) use ($taxonomy_lookup) {
        return $taxonomy_lookup['species_names'][$string] ?? TaxonomyInterface::SPECIES_NAME_UNKNOWN;
      });
    $container->set('genoring.taxonomy', $this->taxonomyServiceMock);

    \Drupal::setContainer($container);
    $this->container = $container;
  }

  /**
   * Test how the data manager adds a file to GenoRing management.
   */
  public function testGetFile() {
    $file_path = __DIR__ . '/../../fixtures/data/datafile.txt';
    $this->assertFileExists($file_path, 'data/datafile.txt test file is missing.');
    $this->markTestIncomplete('No real test done.');
  }

}
